==> members-feign-airport4-20241028.083116-36-sources.jar: com/bizvane/members/feign/service/IntegralFeign.java <==
package com.bizvane.members.feign.service;

import com.bizvane.members.feign.model.bo.*;
import com.bizvane.members.feign.model.vo.MbrIntegralRecordVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

@FeignClient(value="${feign.client.members.name}",path="${feign.client.members.path}/integral")
@Api("积分管理")
public interface IntegralFeign {

    @ApiOperation(value = "增加积分")
    @RequestMapping(value="/add", method = RequestMethod.POST)
    ResponseData<String> add(@RequestBody MbrIntegralAddRequestParam param);

    @ApiOperation(value = "扣减积分")
    @RequestMapping(value="/sub", method = RequestMethod.POST)
    ResponseData<String> sub(@RequestBody MbrIntegralSubRequestParam param);

    @ApiOperation(value = "查询积分流水")
    @RequestMapping(value="/recordlist", method = RequestMethod.POST)
    ResponseData<PageInfo<MbrIntegralRecordVO>> recordlist(@RequestBody MbrIntegralRecordListRequestParam param);

    @ApiOperation(value = "新增批量任务")
    @RequestMapping(value="/addBatchTask", method = RequestMethod.POST)
    ResponseData<String> addBatchTask(@RequestBody MbrIntegralAddBatchTaskRequestParam param);

    @ApiOperation(value = "新增批量任务明细")
    @RequestMapping(value="/addBatchTaskDetail", method = RequestMethod.POST)
    ResponseData<String> addBatchTaskDetail(@RequestBody MbrIntegralAddBatchTaskDetailRequestParam param);
}

==> members-feign-airport4-20241116.025441-83-sources.jar: com/bizvane/members/feign/service/IntegralFeign.java <==
package com.bizvane.members.feign.service;

import com.bizvane.members.feign.model.bo.*;
import com.bizvane.members.feign.model.vo.MbrIntegralRecordVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

@FeignClient(value="${feign.client.members.name}",path="${feign.client.members.path}/integral")
@Api("积分管理")
public interface IntegralFeign {

    @ApiOperation(value = "增加积分")
    @RequestMapping(value="/add", method = RequestMethod.POST)
    ResponseData<String> add(@RequestBody MbrIntegralAddRequestParam param);

    @ApiOperation(value = "扣减积分")
    @RequestMapping(value="/sub", method = RequestMethod.POST)
    ResponseData<String> sub(@RequestBody MbrIntegralSubRequestParam param);

    @ApiOperation(value = "查询积分流水")
    @RequestMapping(value="/recordlist", method = RequestMethod.POST)
    ResponseData<PageInfo<MbrIntegralRecordVO>> recordlist(@RequestBody MbrIntegralRecordListRequestParam param);

    @ApiOperation(value = "查询会员即将过期积分")
    @RequestMapping(value="/getAboutExpireIntegral", method = RequestMethod.POST)
    ResponseData<Integer> getAboutExpireIntegral(@RequestParam("mbrMembersCode") String mbrMembersCode, @RequestParam("expireDay") Integer expireDay);
}
